@@ -1,4 +1,4 @@
-# Copyright 2010-2013 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2013, 2014 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -20,8 +20,7 @@
 Copyright (C) 2008 Reahl Software Services (Pty) Ltd.  All rights reserved. (www.reahl.org)
 
 """
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import print_function, unicode_literals, absolute_import, division
 
 from reahl.component.config import Configuration, EntryPointClassList
 
